@@ -1,6 +1,6 @@
 /***************************************************************************
- *   copyright       : (C) 2003-2009 by Pascal Brachet                     *
- *   http://www.xm1math.net/texmaker/                                      *
+ *   copyright            : (C) 2003 by Pascal Brachet                     *
+ *                                                                         *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -17,16 +17,16 @@
 #include <qcolor.h>
 #include "latexeditor.h"
 #include "linenumberwidget.h"
-#include "findwidget.h"
-#include "hunspell/hunspell.hxx"
 
+/**
+  *@author Pascal Brachet
+  */
 class LatexEditorView : public QWidget  {
    Q_OBJECT
 public: 
-	LatexEditorView(QWidget *parent, QFont & efont,bool line, QColor colMath, QColor colCommand, QColor colKeyword,bool inlinespelling=false, QString ignoredWords="",Hunspell *spellChecker=0);
+	LatexEditorView(QWidget *parent, const char *name, QFont & efont,bool line);
 	~LatexEditorView();
   LatexEditor *editor;
-  FindWidget *findwidget;
   void changeSettings(QFont & new_font,bool line);
 private:
   LineNumberWidget* m_lineNumberWidget;
