@@ -1,6 +1,6 @@
 /***************************************************************************
- *   copyright       : (C) 2003-2009 by Pascal Brachet                     *
- *   http://www.xm1math.net/texmaker/                                      *
+ *   copyright            : (C) 2003 by Pascal Brachet                     *
+ *                                                                         *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -12,10 +12,9 @@
 #ifndef __linenumberwidget_h
 #define __linenumberwidget_h
 
-#include <QtGui>
-#include <QWidget>
-#include <QFont>
-#include <QPaintEvent>
+#include <qwidget.h>
+#include <qpixmap.h>
+#include <qfont.h>
 #include "latexeditor.h"
 
 
@@ -23,20 +22,21 @@ class LineNumberWidget: public QWidget
 {
     Q_OBJECT
 public:
-    LineNumberWidget(LatexEditor*, QWidget* parent);
+    LineNumberWidget(LatexEditor*, QWidget* =0, const char* =0);
     virtual ~LineNumberWidget();
 
 public slots:
-    void doRepaint() { repaint(); }
+    void doRepaint() { repaint( FALSE ); }
     void setFont(QFont efont);
 
 protected:
+    virtual void resizeEvent( QResizeEvent* );
     virtual void paintEvent( QPaintEvent* );
-    virtual void mousePressEvent(QMouseEvent *e);
 
 private:
     LatexEditor* m_editor;
     QFont numfont;
+    QPixmap buffer;
 };
 
 #endif // __linenumberwidget_h
