@@ -1,6 +1,6 @@
 /***************************************************************************
- *   copyright       : (C) 2003-2009 by Pascal Brachet                     *
- *   http://www.xm1math.net/texmaker/                                      *
+ *   copyright            : (C) 2003 by Pascal Brachet                     *
+ *                                                                         *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -11,21 +11,48 @@
 
 #ifndef QUICKDOCUMENTDIALOG_H
 #define QUICKDOCUMENTDIALOG_H
-
-#include "ui_quickdocumentdialog.h"
+#include <qlabel.h>
+#include <qlayout.h>
+#include <qcombobox.h>
+#include <qcheckbox.h>
+#include <qpushbutton.h>
+#include <qdialog.h>
+#include <qlistbox.h>
+#include <qlineedit.h>
+#include <qstringlist.h>
 #include "addoptiondialog.h"
 
 
 
-class QuickDocumentDialog : public QDialog  {
+/**
+  *@author Brachet Pascal
+  */
+
+class quickdocumentdialog : public QDialog  {
    Q_OBJECT
 public:
-	QuickDocumentDialog(QWidget *parent=0, const char *name=0);
-	~QuickDocumentDialog();
-	Ui::QuickDocumentDialog ui;
+	quickdocumentdialog(QWidget *parent=0, const char *name=0);
+	~quickdocumentdialog();
 
 public:
+	QLabel *QLabel_1;
+	QLabel *QLabel_2;
+	QLabel *QLabel_3;
+	QLabel *QLabel_4;
+  QLabel *QLabel_5;
+  QLabel *QLabel_6;
+  QLabel *QLabel_7;
+  QLineEdit *LineEdit1,*LineEdit2 ;
+  QComboBox *combo1;
+  QComboBox *combo2;
+  QComboBox *combo3;
+  QComboBox *combo4;
+  QCheckBox* checkbox1, *checkbox2;
+	QPushButton *buttonOk;
+	QPushButton *buttonCancel;
+	QPushButton *userClassBtn, *userPaperBtn, *userEncodingBtn, *userOptionsBtn;
 
+  QListBox *availableBox;
   QStringList otherClassList, otherPaperList, otherEncodingList, otherOptionsList;
 
 public slots:
