@@ -1,6 +1,6 @@
 /***************************************************************************
- *   copyright       : (C) 2003-2009 by Pascal Brachet                     *
- *   http://www.xm1math.net/texmaker/                                      *
+ *   copyright            : (C) 2003 by Pascal Brachet                     *
+ *                                                                         *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -12,17 +12,42 @@
 #ifndef REPLACEDIALOG_H
 #define REPLACEDIALOG_H
 
-#include "ui_replacedialog.h"
+#include <qvariant.h>
+#include <qdialog.h>
 #include "latexeditor.h"
+class QVBoxLayout; 
+class QHBoxLayout; 
+class QGridLayout; 
+class QButtonGroup;
+class QCheckBox;
+class QComboBox;
+class QLabel;
+class QPushButton;
+class QRadioButton;
 
 class ReplaceDialog : public QDialog
 { 
     Q_OBJECT
 
 public:
-    ReplaceDialog(QWidget* parent = 0, const char* name = 0, Qt::WFlags fl = 0 );
+    ReplaceDialog(QWidget* parent = 0, const char* name = 0, bool modal = FALSE, WFlags fl = 0 );
     ~ReplaceDialog();
-    Ui::ReplaceDialog ui;
+
+    QLabel* TextLabel2;
+    QLabel* TextLabel1;
+    QComboBox* comboFind;
+    QComboBox* comboReplace;
+    QPushButton* buttonReplace;
+    QPushButton* buttonReplaceAll;
+    QPushButton* PushButton2;
+    QButtonGroup* ButtonGroup1;
+    QCheckBox* checkWords;
+    QCheckBox* checkCase;
+    QCheckBox* checkBegin;
+    QButtonGroup* ButtonGroup2;
+    QRadioButton* radioForward;
+    QRadioButton* radioBackward;
+
 
 public slots:
     virtual void doReplace();
@@ -30,7 +55,14 @@ public slots:
     void SetEditor(LatexEditor *ed);
 
 protected:
+    QGridLayout* ReplaceDialogLayout;
+    QGridLayout* Layout3;
+    QHBoxLayout* Layout5;
+    QVBoxLayout* ButtonGroup1Layout;
+    QVBoxLayout* ButtonGroup2Layout;
+
     LatexEditor *editor;
+    QObject *formWindow;
 };
 
 #endif // REPLACEDIALOG_H
