@@ -1,6 +1,6 @@
 /***************************************************************************
- *   copyright       : (C) 2003-2009 by Pascal Brachet                     *
- *   http://www.xm1math.net/texmaker/                                      *
+ *   copyright            : (C) 2003 by Pascal Brachet                     *
+ *                                                                         *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -12,31 +12,43 @@
 #ifndef USERMENUDIALOG_H
 #define USERMENUDIALOG_H
 
-#include <QString>
-#include "ui_usermenudialog.h"
+#include <qlayout.h>
+#include <qlabel.h>
+#include <qlineedit.h>
+#include <qcombobox.h>
+#include <qdialog.h>
+#include <qpushbutton.h>
+#include <qstring.h>
 
 typedef QString userlist[10];
 
-class UserMenuDialog : public QDialog
+class usermenudialog : public QDialog
 {
     Q_OBJECT
 
 public:
-    UserMenuDialog( QWidget* parent = 0, QString name="");
-    ~UserMenuDialog();
-    Ui::UserMenuDialog ui;
+    usermenudialog( QWidget* parent = 0, const char* name = 0);
+    ~usermenudialog();
 
     userlist Name,Tag;
 
 private:
     int previous_index;
+    QLineEdit *tagedit;
+    QLineEdit *itemedit;
+    QComboBox *combo1;
+    QLabel* label1;
+    QLabel* label2;
+	  QPushButton *buttonOk;
+	  QPushButton *buttonCancel;
 
 public slots:
-    void init();
+    void init();        
 
 private slots:
     void change(int index);
     void slotOk();
+
 };
 
 #endif // USERMENUDIALOG_H
