@@ -1,6 +1,6 @@
 /***************************************************************************
- *   copyright       : (C) 2003-2009 by Pascal Brachet                     *
- *   http://www.xm1math.net/texmaker/                                      *
+ *   copyright            : (C) 2003 by Pascal Brachet                     *
+ *                                                                         *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -12,23 +12,37 @@
 #ifndef USERTOOLDIALOG_H
 #define USERTOOLDIALOG_H
 
-#include <QString>
-#include "ui_usertooldialog.h"
+#include <qwidget.h>
+#include <qdialog.h>
+#include <qlayout.h>
+#include <qlabel.h>
+#include <qlineedit.h>
+#include <qcombobox.h>
+#include <qpushbutton.h>
+#include <qstring.h>
 
 typedef QString userCd[5];
 
+/**
+  *@author Pascal Brachet
+  */
 
-class UserToolDialog : public QDialog  {
+class usertooldialog : public QDialog  {
    Q_OBJECT
 public: 
-	UserToolDialog(QWidget *parent=0, QString name="");
-	~UserToolDialog();
-	Ui::UserToolDialog ui;
+	usertooldialog(QWidget *parent=0, const char *name=0);
+	~usertooldialog();
 
       userCd Name,Tool;
 
 private:
     int previous_index;
+    QLineEdit *itemedit, *tooledit;
+    QComboBox *combo1;
+    QLabel* label1;
+    QLabel* label2;
+	  QPushButton *buttonOk;
+	  QPushButton *buttonCancel;
 
 public slots:
     void init();
